@@ -431,7 +431,7 @@ misc_spec_locale (const gchar *prgname)
 #ifdef LOCALEDIR
   return LOCALEDIR;
 #else /* not LOCALEDIR */
-  const static gchar *locale = NULL;
+  static gchar *locale = NULL;
   gchar *dirname, *path;
 # if GLIB_CHECK_VERSION(2,6,0) && defined (G_OS_WIN32)
   gchar *tmp;
@@ -466,6 +466,141 @@ misc_spec_locale (const gchar *prgname)
 }
 
 
+/******************************************************************************
+*                                                                             *
+* ja:クローズボタン関数群                                                     *
+*                                                                             *
+******************************************************************************/
+/*  ja:クローズボタンのイメージを取得する
+    RET,イメージ,NULL:エラー                                                */
+GtkWidget *
+misc_close_image (void)
+{
+  GtkIconSet *icon_set;
+  GtkWidget *image = NULL;
+
+  icon_set = gtk_icon_factory_lookup_default (GTK_STOCK_CLOSE);
+  if (icon_set)
+    {
+      GdkPixbuf *pixbuf;
+
+      pixbuf = gtk_icon_set_render_icon (icon_set,
+                                         gtk_widget_get_default_style (),
+                                         GTK_TEXT_DIR_NONE,
+                                         GTK_STATE_NORMAL,
+                                         GTK_ICON_SIZE_MENU,
+                                         NULL, NULL);
+      if (pixbuf)
+        {
+          if (gdk_pixbuf_get_colorspace (pixbuf) == GDK_COLORSPACE_RGB
+                            && gdk_pixbuf_get_n_channels (pixbuf) == 4
+                            && gdk_pixbuf_get_has_alpha (pixbuf)
+                            && gdk_pixbuf_get_bits_per_sample (pixbuf) == 8)
+            {
+              int width, height, rowstride;
+              gint x, y, left, top, right, bottom;
+              guchar *pixels;
+
+              pixels = gdk_pixbuf_get_pixels (pixbuf);
+              width = gdk_pixbuf_get_width (pixbuf);
+              height = gdk_pixbuf_get_height (pixbuf);
+              rowstride = gdk_pixbuf_get_rowstride (pixbuf);
+              for (x = 0; x < width; x++)
+                for (y = 0; y < height; y++)
+                  if (pixels[y * rowstride + x * 4 + 3] > 0)
+                    goto loop_left;
+              loop_left: left = x;
+              for (y = 0; y < height; y++)
+                for (x = 0; x < width; x++)
+                  if (pixels[y * rowstride + x * 4 + 3] > 0)
+                    goto loop_top;
+              loop_top: top = y;
+              for (x = width - 1; x >= 0; x--)
+                for (y = 0; y < height; y++)
+                  if (pixels[y * rowstride + x * 4 + 3] > 0)
+                    goto loop_right;
+              loop_right: right = x;
+              for (y = height - 1; y >= 0; y--)
+                for (x = 0; x < width; x++)
+                  if (pixels[y * rowstride + x * 4 + 3] > 0)
+                    goto loop_bottom;
+              loop_bottom: bottom = y;
+              if (left <= right && top <= bottom)
+                {
+                  int w, h, r;
+                  guchar *p;
+                  gint i;
+                  GdkPixbuf *b;
+
+                  w = right - left + 1;
+                  h = bottom - top + 1;
+                  b = gdk_pixbuf_new (GDK_COLORSPACE_RGB, TRUE, 8, w, h);
+                  p = gdk_pixbuf_get_pixels (b);
+                  r = gdk_pixbuf_get_rowstride (b);
+                  for (x = 0; x < w; x++)
+                    for (y = 0; y < h; y++)
+                      for (i = 0; i < 4; i++)
+                        p[y * r + x * 4 + i]
+                        = pixels[(y + top) * rowstride + (x + left) * 4 + i];
+                  image = gtk_image_new_from_pixbuf (b);
+                  g_object_unref (b);
+                }
+            }
+          g_object_unref (pixbuf);
+        }
+    }
+  if (!image)
+    image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
+  if (!image)
+    {
+      GdkPixbuf *pixbuf;
+      const static gchar *xpm[] = {
+"12 13 4 1",
+"   c None",
+"X  c #000000",
+"+  c #808080",
+".  c #FFFFFF",
+"+++++++++++.",
+"+.........+.",
+"+.        +.",
+"+.XX    XX+.",
+"+. XX  XX +.",
+"+.  XXXX  +.",
+"+.   XX   +.",
+"+.  XXXX  +.",
+"+. XX  XX +.",
+"+.XX    XX+.",
+"+.        +.",
+"+++++++++++.",
+"............"};
+
+      pixbuf = gdk_pixbuf_new_from_xpm_data (xpm);
+      image = gtk_image_new_from_pixbuf (pixbuf);
+      g_object_unref (pixbuf);
+    }
+  return image;
+}
+
+
+/*  ja:クローズボタンを取得する
+    RET,ボタン,NULL:エラー                                                  */
+GtkWidget *
+misc_close_button (void)
+{
+  GtkWidget *button = NULL, *image;
+
+  image = misc_close_image ();
+  if (image)
+    {
+      button = gtk_button_new ();
+      gtk_button_set_relief (GTK_BUTTON (button), GTK_RELIEF_NONE);
+      gtk_container_add (GTK_CONTAINER (button), image);
+      gtk_widget_show (image);
+    }
+  return button;
+}
+
+
 /******************************************************************************
 *                                                                             *
 * ja:低レベル関数群                                                           *
