@@ -1,10 +1,10 @@
 /*
     orzcharset
-    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,24 +13,12 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "orzcharset.h"
 #include <gdk/gdkkeysyms.h>
 
 
-static void orz_charset_class_init (OrzCharsetClass *klass);
-static void orz_charset_init       (OrzCharset      *charset);
-
-
-#if GTK_CHECK_VERSION(2,4,0)
-static GtkComboBoxEntryClass *parent_class = NULL;
-#else /* not GTK_CHECK_VERSION(2,4,0) */
-static GtkComboClass *parent_class = NULL;
-#endif /* not GTK_CHECK_VERSION(2,4,0) */
-
-
 enum
 {
   ACTIVATE_SIGNAL,
@@ -45,44 +33,16 @@ static gint orz_charset_signals[LAST_SIGNAL] = {0};
 /******************************************************************************
 *                                                                             *
 ******************************************************************************/
-GtkType
-orz_charset_get_type (void)
-{
-  static GType orz_charset_type = 0;
-
-  if (!orz_charset_type)
-    {
-      const static GTypeInfo charset_info =
-      {
-        sizeof (OrzCharsetClass),
-        NULL,               /* base_init */
-        NULL,               /* base_finalize */
-        (GClassInitFunc)orz_charset_class_init,
-        NULL,               /* class_finalize */
-        NULL,               /* class_data */
-        sizeof (OrzCharset),
-        0,                  /* n_preallocs */
-        (GInstanceInitFunc)orz_charset_init,
-      };
-
 #if GTK_CHECK_VERSION(2,4,0)
-      orz_charset_type = g_type_register_static (GTK_TYPE_COMBO_BOX_ENTRY,
-                                            "OrzCharset", &charset_info, 0);
+G_DEFINE_TYPE (OrzCharset, orz_charset, GTK_TYPE_COMBO_BOX_ENTRY);
 #else /* not GTK_CHECK_VERSION(2,4,0) */
-      orz_charset_type = g_type_register_static (GTK_TYPE_COMBO,
-                                            "OrzCharset", &charset_info, 0);
+G_DEFINE_TYPE (OrzCharset, orz_charset, GTK_TYPE_COMBO);
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
-    }
-
-  return orz_charset_type;
-}
 
 
 static void
 orz_charset_class_init (OrzCharsetClass *klass)
 {
-  parent_class = g_type_class_peek_parent (klass);
-
   klass->activate = NULL;
   klass->edited = NULL;
 
