@@ -1,10 +1,10 @@
 /*
     orzhistory
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
-    This program is free software; you can redistribute it and/or modify
+    This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
-    the Free Software Foundation; either version 2 of the License, or
+    the Free Software Foundation, either version 3 of the License, or
     (at your option) any later version.
 
     This program is distributed in the hope that it will be useful,
@@ -13,19 +13,16 @@
     GNU General Public License for more details.
 
     You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+    along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #ifndef __ORZ_HISTORY_H__
 #define __ORZ_HISTORY_H__
 
 
-#include "common.h"
+#include "gcommon.h"
 
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 
 #define ORZ_TYPE_HISTORY            (orz_history_get_type ())
@@ -86,7 +83,7 @@ orz_history_get_type (void) G_GNUC_CONST;
 ******************************************************************************/
 /*  ja:新規作成
     RET,オブジェクト                                                        */
-GObject*
+GObject *
 orz_history_new (void);
 
 
@@ -108,8 +105,8 @@ orz_history_get_file (OrzHistory *history);
 /*  ja:メニューを取得する
     history,オブジェクト
         RET,メニュー                                                        */
-#define orz_history_get_menu(history)                                       \
-                            ((history)?ORZ_HISTORY(history)->menu_shell:NULL)
+GtkWidget *
+orz_history_get_menu (OrzHistory *history);
 
 
 /*  ja:メニューを設定する
@@ -119,7 +116,7 @@ orz_history_get_file (OrzHistory *history);
 void
 orz_history_set_menu (OrzHistory *history,
                       GtkWidget  *menu_shell,
-                      gint        position);
+                      const gint  position);
 
 
 /*  ja:メニューの数を取得する
@@ -138,9 +135,7 @@ orz_history_set_num (OrzHistory *history,
                      const gint  num);
 
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 
 #endif /* __ORZ_HISTORY_H__ */
