@@ -16,6 +16,7 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "abort.h"
+#include "panel.h"
 #include "orz/orzmdi.h"
 
 
@@ -24,10 +25,11 @@ gboolean abort_break;
 
 /******************************************************************************
 *                                                                             *
-* ja:中断関数群                                                               *
+* ja:中断ボックス関数群                                                       *
 *                                                                             *
 ******************************************************************************/
-static GtkWidget *hbox = NULL;
+static gint abort_focus;
+static GtkWidget *abort_box = NULL;
 
 
 /* ja:中断ボタンが押された */
@@ -39,43 +41,56 @@ abort_box_clicked (GtkWidget *widget,
 }
 
 
-/*  ja:中断ボタン取得 */
+/*  ja:中断ボックス取得
+    RET,中断ボックス                                                        */
 GtkWidget *
 abort_box_get_widget (void)
 {
-  if (!hbox)
+  if (!abort_box)
     {
       GtkWidget *button;
 
       button = gtk_button_new_from_stock (GTK_STOCK_STOP);
       g_signal_connect (G_OBJECT (button), "clicked",
                                         G_CALLBACK (abort_box_clicked), NULL);
-      hbox = gtk_hbox_new (FALSE, 0);
-      gtk_box_pack_start (GTK_BOX (hbox), button, FALSE, FALSE, 0);
+      abort_box = gtk_hbox_new (FALSE, 0);
+      gtk_box_pack_start (GTK_BOX (abort_box), button, FALSE, FALSE, 0);
     }
-  return hbox;
+  return abort_box;
 }
 
 
-/*  ja:中断ボタン開始 */
+/*  ja:中断ボックス開始                                                     */
 void
 abort_box_start (void)
 {
+  abort_focus = GTK_WIDGET_HAS_FOCUS (find_entry) ? 1
+              : GTK_WIDGET_HAS_FOCUS (replace_entry) ? 2 : 0;
   gtk_widget_set_sensitive (main_box, FALSE);
-  gtk_widget_show (hbox);
+  gtk_widget_set_sensitive (find_box, FALSE);
+  gtk_widget_show (abort_box);
   abort_break = TRUE;
 }
 
 
-/*  ja:中断ボタン終了 */
+/*  ja:中断ボックス終了                                                     */
 void
 abort_box_end (void)
 {
-  TmaidWindow *tmaid;
-
   gtk_widget_set_sensitive (main_box, TRUE);
-  gtk_widget_hide (hbox);
-  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
-  if (tmaid)
-    gtk_widget_grab_focus (tmaid->drawing);
+  gtk_widget_set_sensitive (find_box, TRUE);
+  gtk_widget_hide (abort_box);
+  switch (abort_focus)
+    {
+      case 1: gtk_widget_grab_focus (find_entry); break;
+      case 2: gtk_widget_grab_focus (replace_entry); break;
+      default:
+        {
+          TmaidWindow *tmaid;
+
+          tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
+          if (tmaid)
+            gtk_widget_grab_focus (tmaid->drawing);
+        }
+    }
 }
