@@ -23,6 +23,7 @@
 #include "ftype.h"
 #include "general.h"
 #include "jump.h"
+#include "panel.h"
 #include "print.h"
 #include "prop.h"
 #include "reload.h"
@@ -32,6 +33,7 @@
 #include "valchr.h"
 #include "version.h"
 #include "misc/fileio.h"
+#include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 #include "orz/orzpref.h"
@@ -946,7 +948,7 @@ command_all (GtkWidget *widget,
                         G_CALLBACK (signal_value_changed_hscroll), tmaid,
                         0, edit_get_width_max (tmaid) + 1, sx, tmaid->top.x);
   if (tmaid->top.y != top.y)
-    misc_set_scroll_bar(tmaid->vscroll,
+    misc_set_scroll_bar (tmaid->vscroll,
                         G_CALLBACK (signal_value_changed_vscroll), tmaid,
                         0, tmaid->max, sy, tmaid->top.y);
   gtk_widget_queue_draw (tmaid->drawing);
@@ -957,51 +959,10 @@ void
 command_find (GtkWidget *widget,
               gpointer   user_data)
 {
-  FindString fd;
-  TmaidWindow *tmaid;
-
-  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
-  fd.text = NULL;
-  fd.arrow = find_arrow;
-  fd.ignorecase = find_ignorecase;
-  if (tmaid->select.x >= 0)
-    fd.arrow = tmaid->cursor.y < tmaid->select.y
-                                        || (tmaid->cursor.y == tmaid->select.y
-                                        && tmaid->cursor.x < tmaid->select.x);
-  if (find_dialog (&fd))
-    {
-      gint i;
-
-      set_menu_bar (tmaid);
-      find_arrow = fd.arrow;
-      find_ignorecase = fd.ignorecase;
-      for (i = 0; i < find_num; i++)
-        if (g_strcmp (fd.text, find_text[i]) == 0)
-          break;
-      if (i == find_num)
-        {
-          if (find_num >= 32)
-            g_free (find_text[31]);
-          else
-            find_num++;
-          g_memmove (find_text + 1, find_text,
-                                            (find_num - 1) * sizeof (gchar *));
-          find_text[0] = fd.text;
-        }
-      else
-        {
-          g_free (fd.text);
-          if (i > 0)
-            {
-              gchar *text;
-
-              text = find_text[i];
-              g_memmove (find_text + 1, find_text, i * sizeof (gchar *));
-              find_text[0] = text;
-            }
-        }
-      command_next (widget, GINT_TO_POINTER (TRUE));
-    }
+  if (GTK_WIDGET_HAS_FOCUS (find_entry) && !GTK_WIDGET_VISIBLE (replace_combo))
+    find_box_end ();
+  else
+    find_box_start ();
 }
 
 
@@ -1009,17 +970,18 @@ void
 command_next (GtkWidget *widget,
               gpointer   user_data)
 {
+  gboolean result;
   TmaidWindow *tmaid;
 
   tmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   /* ja:中断ボタン */
   abort_box_start ();
-  find_operation (tmaid, &tmaid->cursor, &tmaid->select, find_text[0],
+  result = find_operation (tmaid, &tmaid->cursor, &tmaid->select, find_text[0],
                         GPOINTER_TO_INT (user_data) ? find_arrow : !find_arrow,
                                                             find_ignorecase);
   /* ja:中断ボタン */
   abort_box_end ();
-  if (abort_break && tmaid->select.x < 0)
+  if (abort_break && !result)
     {
       GtkWidget *dialog;
 
@@ -1031,7 +993,6 @@ command_next (GtkWidget *widget,
                                     G_CALLBACK (misc_dialog_key_press), NULL);
       gtk_dialog_run (GTK_DIALOG (dialog));
       gtk_widget_destroy (dialog);
-      set_menu_bar (tmaid);
     }
 }
 
@@ -1040,156 +1001,10 @@ void
 command_replace (GtkWidget *widget,
                  gpointer   user_data)
 {
-  gboolean replace = FALSE;
-  gint page_num, result;
-  TmaidWindow *tmaid;
-  ReplaceString rp;
-
-  page_num = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi));
-  tmaid = orz_mdi_get_data (ORZ_MDI (mdi), page_num);
-  rp.src = rp.dst = NULL;
-  rp.arrow = replace_arrow;
-  rp.ignorecase = replace_ignorecase;
-  if (tmaid->select.x >= 0)
-    rp.arrow = tmaid->cursor.y < tmaid->select.y
-                                        || (tmaid->cursor.y == tmaid->select.y
-                                        && tmaid->cursor.x < tmaid->select.x);
-  result = replace_dialog (&rp);
-  if (result != REPLACE_CANCEL)
-    {
-      gchar *text;
-      gint i, count = 0;
-      GdkPoint select;
-      ReplaceInfo ri;
-
-      set_menu_bar (tmaid);
-      replace_arrow = rp.arrow;
-      replace_ignorecase = rp.ignorecase;
-      for (i = 0; i < find_num; i++)
-        if (g_strcmp (rp.src, find_text[i]) == 0)
-          break;
-      if (i == find_num)
-        {
-          if (find_num >= 32)
-            g_free (find_text[31]);
-          else
-            find_num++;
-          g_memmove (find_text + 1, find_text,
-                                            (find_num - 1) * sizeof (gchar *));
-          find_text[0] = rp.src;
-        }
-      else
-        {
-          g_free (rp.src);
-          text = find_text[i];
-          g_memmove (find_text + 1, find_text, i * sizeof (gchar *));
-          find_text[0] = text;
-        }
-      if (rp.dst && rp.dst[0] != '\0')
-        {
-          for (i = 0; i < replace_num; i++)
-            if (g_strcmp (rp.dst, replace_text[i]) == 0)
-              break;
-          if (i == replace_num)
-            {
-              if (replace_num >= 32)
-                g_free (replace_text[31]);
-              else
-                replace_num++;
-              g_memmove (replace_text + 1, replace_text,
-                                        (replace_num - 1) * sizeof (gchar *));
-              replace_text[0] = rp.dst;
-            }
-          else
-            {
-              g_free (rp.dst);
-              text = replace_text[i];
-              g_memmove (replace_text + 1, replace_text, i * sizeof (gchar *));
-              replace_text[0] = text;
-            }
-          ri.dst = replace_text[0];
-        }
-      else
-        {
-          g_free (rp.dst);
-          ri.dst = NULL;
-        }
-      select = tmaid->select;
-      ri.arrow = replace_arrow;
-      ri.ignorecase = replace_ignorecase;
-      /* ja:中断ボタン */
-      abort_box_start ();
-      do
-        {
-          gint bytes, data_pos;
-          TmaidHistory *d;
-
-          find_operation (tmaid, &tmaid->cursor, &select, find_text[0],
-                                            replace_arrow, replace_ignorecase);
-          if (tmaid->select.x < 0)
-            break;
-          replace = TRUE;
-          bytes = edit_get_sel_bytes (tmaid, &tmaid->select, &tmaid->cursor);
-          if (result != REPLACE_ALL)
-            {
-              ri.src = g_malloc (bytes + 1);
-              edit_cpy_sel_mem (tmaid, &tmaid->select, &tmaid->cursor, ri.src);
-              ri.src[bytes] = '\0';
-              ri.start = tmaid->select;
-              ri.end = tmaid->cursor;
-              result = repinfo_dialog (&ri);
-              g_free (ri.src);
-              if (result == REPLACE_CANCEL || result == REPLACE_NEXT)
-                continue;
-          }
-          if (select.x >= 0 && tmaid->cursor.y == select.y && replace_arrow)
-            data_pos = edit_get_data_pos (tmaid, select.x, select.y, FALSE);
-          else
-            data_pos = -1;
-          d = edit_operation (tmaid, ri.dst, g_strlen (ri.dst),
-                                                        replace_arrow, TRUE);
-          if (data_pos >= 0)
-            select.x = edit_get_screen_pos (tmaid,
-                            data_pos + g_strlen (ri.dst) - bytes, select.y);
-          if (result == REPLACE_OK || result == REPLACE_ALL)
-            count++;
-          d->next = tmaid->undo;
-          tmaid->undo = d;
-          if (delete_list (&tmaid->redo) > 0 || !d->next)
-            set_menu_bar (tmaid);
-          orz_mdi_set_edited (ORZ_MDI (mdi), page_num, TRUE);
-        }
-      while (result != REPLACE_CANCEL);
-      /* ja:中断ボタン */
-      abort_box_end ();
-      if (!replace)
-        {
-          GtkWidget *dialog;
-
-          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-                            _("'%s' was not fount."), find_text[0]);
-          g_signal_connect (G_OBJECT (dialog), "key-press-event",
-                                    G_CALLBACK (misc_dialog_key_press), NULL);
-          gtk_dialog_run (GTK_DIALOG (dialog));
-          gtk_widget_destroy (dialog);
-        }
-      else if (result == REPLACE_ALL)
-        {
-          GtkWidget *dialog;
-
-          dialog = gtk_message_dialog_new (GTK_WINDOW (window),
-                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
-                            GTK_MESSAGE_INFO, GTK_BUTTONS_OK,
-                            _("%d strings were replaced"), count);
-          g_signal_connect (G_OBJECT (dialog), "key-press-event",
-                                    G_CALLBACK (misc_dialog_key_press), NULL);
-          gtk_dialog_run (GTK_DIALOG (dialog));
-          gtk_widget_destroy (dialog);
-        }
-      set_menu_bar (tmaid);
-    }
+  if (GTK_WIDGET_HAS_FOCUS (replace_entry))
+    find_box_end ();
+  else
+    replace_box_start ();
 }
 
 
