@@ -25,36 +25,21 @@
 G_BEGIN_DECLS
 
 
-#define REPLACE_CANCEL -1
-#define REPLACE_OK 1
-#define REPLACE_ALL 2
-#define REPLACE_NEXT 0
+#define REPLACE_TEXT 16
 
 
-typedef struct _ReplaceString
-{
-  gboolean arrow;
-  gboolean ignorecase;
-  gchar *src, *dst;
-} ReplaceString;
-
-
-extern gboolean replace_arrow;              /* ja:検索の設定 */
-extern gboolean replace_ignorecase;         /* ja:置換の設定 */
-extern gchar *replace_text[32];             /* ja:置換する文字列 */
-extern gint replace_num;                    /* ja:登録されている置換文字列 */
+extern gchar *replace_text[REPLACE_TEXT];   /* ja:置換する文字列 */
 
 
 /******************************************************************************
 *                                                                             *
-* ja:置換ダイアログ関数群                                                     *
+* ja:置換関数群                                                               *
 *                                                                             *
 ******************************************************************************/
-/*  ja:置換ダイアログ表示
-     rp,置換情報
-    RET,REPLACE_OK,REPLACE_NEXT,REPLACE_ALL,REPLACE_CANCEL                  */
-gint
-replace_dialog (ReplaceString *rp);
+/*  ja:置換
+    mode,モード                                                             */
+void
+replace_operation (gint mode);
 
 
 G_END_DECLS
