@@ -19,7 +19,10 @@
 #include "edit.h"
 #include "file.h"
 #include "general.h"
+#include "menu.h"
+#include "panel.h"
 #include "sigfile.h"
+#include "misc/misc.h"
 #include "orz/orzmdi.h"
 
 
@@ -207,6 +210,7 @@ signal_destroy_draw (GtkWidget   *widget,
       gtk_statusbar_pop (GTK_STATUSBAR (status),
             gtk_statusbar_get_context_id (GTK_STATUSBAR (status), "Status"));
       gtk_label_set_text (GTK_LABEL (label_cursor), "");
+      find_box_end ();
     }
   /* ja:メモリを解放する */
   g_object_unref (tmaid->layout);
