@@ -20,7 +20,6 @@
 
 
 #include "gcommon.h"
-#include "misc/misc.h"
 
 
 G_BEGIN_DECLS
@@ -120,6 +119,7 @@ extern gint ftnum;                      /* ja:ファイルタイプの数 */
 #if GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32)
 extern gint findex;                     /* ja:ファイルタイプのフィルタ */
 #endif /* GTK_CHECK_VERSION(2,4,0) || defined (G_OS_WIN32) */
+extern gint license;                    /* ja:ライセンス */
 extern gint tcount;                     /* ja:ファイルタイプのカウンタ */
 extern guint timer_id;                  /* ja:タイマID */
 extern FileType *ftype;                 /* ja:ファイルタイプ */
@@ -137,9 +137,6 @@ extern GtkWidget *main_box;             /* ja:メインボックス */
 extern PangoFontDescription *system_font;
 extern GdkColor system_color[12];
 extern GtkTargetEntry targets[4];   /* ja:Text maidが提供可能なセレクション */
-extern MiscCreateMenuEntry menu_entries[];
-extern MiscCreateMenuEntry popup_entries[];
-extern MiscCreateToolbarEntry toolbar_entries[];
 
 
 G_END_DECLS
